@@ -145,7 +145,7 @@ c     psneigh  Parallel ARPACK compute Ritz values and error bounds routine.
 c     psngets  Parallel ARPACK reorder Ritz values and error bounds routine.
 c     ssortc   ARPACK sorting routine.
 c     pivout   Parallel ARPACK utility routine that prints integers.
-c     second   ARPACK utility routine for timing.
+c     arscnd   ARPACK utility routine for timing.
 c     psmout   Parallel ARPACK utility routine that prints matrices
 c     psvout   ARPACK utility routine that prints vectors.
 c     pslamch  ScaLAPACK routine that determines machine constants.
@@ -252,7 +252,7 @@ c     %----------------------%
 c
       external   scopy, psgetv0, psnaitr, snconv, 
      &           psneigh, psngets, psnapps,
-     &           psvout, pivout, second
+     &           psvout, pivout, arscnd
 c
 c     %--------------------%
 c     | External Functions |
@@ -274,7 +274,7 @@ c     %-----------------------%
 c
       if (ido .eq. 0) then
 c 
-         call second (t0)
+         call arscnd (t0)
 c 
          msglvl = mnaup2
 c 
@@ -776,7 +776,7 @@ c        | the first step of the next call to psnaitr. |
 c        %---------------------------------------------%
 c
          cnorm = .true.
-         call second (t2)
+         call arscnd (t2)
          if (bmat .eq. 'G') then
             nbx = nbx + 1
             call scopy (n, resid, 1, workd(n+1), 1)
@@ -801,7 +801,7 @@ c        | WORKD(1:N) := B*RESID            |
 c        %----------------------------------%
 c
          if (bmat .eq. 'G') then
-            call second (t3)
+            call arscnd (t3)
             tmvbx = tmvbx + (t3 - t2)
          endif
 c
@@ -841,7 +841,7 @@ c     %------------%
 c     | Error Exit |
 c     %------------%
 c
-      call second (t1)
+      call arscnd (t1)
       tnaup2 = t1 - t0
 c     
  9000 continue
