@@ -137,7 +137,7 @@ c     pcneigh  Parallel ARPACK compute Ritz values and error bounds routine.
 c     pcngets  Parallel ARPACK reorder Ritz values and error bounds routine.
 c     csortc   ARPACK sorting routine.
 c     pivout   Parallel ARPACK utility routine that prints integers.
-c     second   ARPACK utility routine for timing.
+c     arscnd   ARPACK utility routine for timing.
 c     pcmout   Parallel ARPACK utility routine that prints matrices
 c     pcvout   Parallel ARPACK utility routine that prints vectors.
 c     psvout   ARPACK utility routine that prints vectors.
@@ -250,7 +250,7 @@ c     | External Subroutines |
 c     %----------------------%
 c
       external   ccopy, pcgetv0, pcnaitr, pcneigh, pcngets, pcnapps,
-     &           csortc, cswap, pcmout, pcvout, pivout, second
+     &           csortc, cswap, pcmout, pcvout, pivout, arscnd
 c
 c     %--------------------%
 c     | External functions |
@@ -274,7 +274,7 @@ c     %-----------------------%
 c
       if (ido .eq. 0) then
 c 
-         call second (t0)
+         call arscnd (t0)
 c 
          msglvl = mcaup2
 c 
@@ -740,7 +740,7 @@ c        | the first step of the next call to pcnaitr. |
 c        %---------------------------------------------%
 c
          cnorm = .true.
-         call second (t2)
+         call arscnd (t2)
          if (bmat .eq. 'G') then
             nbx = nbx + 1
             call ccopy (n, resid, 1, workd(n+1), 1)
@@ -765,7 +765,7 @@ c        | WORKD(1:N) := B*RESID            |
 c        %----------------------------------%
 c
          if (bmat .eq. 'G') then
-            call second (t3)
+            call arscnd (t3)
             tmvbx = tmvbx + (t3 - t2)
          end if
 c 
@@ -806,7 +806,7 @@ c     %------------%
 c     | Error Exit |
 c     %------------%
 c
-      call second (t1)
+      call arscnd (t1)
       tcaup2 = t1 - t0
 c     
  9000 continue
